@@ -34,7 +34,7 @@ class bot:
 		self.bot = commands.Bot(command_prefix=self.prefix)
 		if self.logging == 'advanced':
 			print(green(f"[{time.asctime(time.localtime(time.time()))}]"), f"\032 Bot made with prefix [{self.prefix}]")
-		else if self.logging == 'normal':
+		elif self.logging == 'normal':
 			print(f"[{time.asctime(time.localtime(time.time()))}]", f"\032 Bot made with prefix [{self.prefix}]")
 		else:
 			pass
@@ -45,7 +45,7 @@ class bot:
 		async def on_ready():
 			if self.logging == 'advanced':
 				print(green(f"[{time.asctime(time.localtime(time.time()))}]"), f"\032 Bot online.")
-			else if self.logging == 'normal':
+			elif self.logging == 'normal':
 				print(f"[{time.asctime(time.localtime(time.time()))}]", f"\032 Bot online.")
 			else:
 				pass
@@ -54,4 +54,20 @@ class bot:
 
 		self.bot.run(token)
 
+	def loadCogs(self, cogs):
+		for cog in cogs:
+			try:
+				print(yellow(f"[{time.asctime(time.localtime(time.time()))}]"), f"\032 Loading [{cogs[cog]}]")
+				self.bot.load_extension(cogs[cog])
+				print(green(f"[{time.asctime(time.localtime(time.time()))}]"), f"\032 Loaded [{cogs[cog]}]")
+			except:
+				print(red(f"[{time.asctime(time.localtime(time.time()))}]"), f"\032 Failed To Load [{cogs[cog]}]")
+	def get(self):
+		def getBot(self):
+			return self.bot
 
+		def getSettings(self):
+			return {'logging': self.logging, "prefix": self.prefix}
+
+		def getAll(self):
+			return {'settings': {'logging': self.logging, "prefix": self.prefix}, "bot": self.bot}
\ No newline at end of file
